Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4)

Unified Diff: tests/language/class_override_test.dart

Issue 22685007: Implement updated method overriding rules in the vm. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/language/class_override_negative_test.dart ('k') | tests/language/language.status » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/language/class_override_test.dart
===================================================================
--- tests/language/class_override_test.dart (revision 25796)
+++ tests/language/class_override_test.dart (working copy)
@@ -2,19 +2,23 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// 8.1 Methods: It is a compile-time error if a method m1 overrides
// a method m2 and has a different number of required parameters.
class A {
foo() {}
}
class B extends A {
- foo(a) { }
+ foo(a) {} /// 00: static type warning
}
main() {
B instance = new B();
- instance.foo(1);
+ try {
+ instance.foo();
+ } on NoSuchMethodEror catch (error) { /// 00: continued
+ } finally {
+ }
print("Success");
}
« no previous file with comments | « tests/language/class_override_negative_test.dart ('k') | tests/language/language.status » ('j') | no next file with comments »
@@ -2,19 +2,23 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// 8.1 Methods: It is a compile-time error if a method m1 overrides
-// a method m2 and has a different number of required parameters.
+// It is a static warning if a method m1 overrides a method m2 and has a
+// different number of required parameters.
class A {
foo() {}

Powered by Google App Engine
This is Rietveld 408576698